@@ -2,6 +2,9 @@
 # adding client side aggregation
 #    name="yokr",
 #    version="0.3.02"
+#    2021-0-29 changed flush_cache(forceUpload=True)  to allow one upload of 
+#              data without data withou waiting a minimal time since 
+#              last regular upload
 import builtins
 import datetime
 import functools
@@ -104,7 +107,7 @@ class YkrCacheEnv:
         self.checkResourceFiles_default = True
         self.checkResourceFiles_P_default = True
         self.checkResourceFiles_I_default = False
-        self.max_result_size_default = 10000
+        self.max_result_size_default = 20000 # TODO
 
         self.cmpDescription_default =\
             "Enter a one line short description of the company"
@@ -154,6 +157,7 @@ class YkrCacheEnv:
                 ('UsedEntities', 'LastDate', 'InstanceDataAgg')
             ]
         self.libsLoaded_default = set()
+        self.forceLoadUsed = False
         self.libsWithNoDetails_default =  \
             set(['abc', 'ast', 'asyncio', 'autoreload', 'base64', 'bdb',
                  'bisect', 'bz2', 'cProfile', 'calendar', 'cmd', 'code',
@@ -180,24 +184,47 @@ class YkrCacheEnv:
                  'weakref', 'win32api', 'win32com', 'win32security', 'xml',
                  'zipfile'])
 
-
 def _ykrUpdate(df=None, upload=True, removeHistory=True, forceUpload=False):
     if df is not None:
         _ykrUpdateInfo(df=df)
-    minFromLastUpload = (time.time() - _yCE.uploadLastTime) / 60.0
-    minFromLastUploadAttempt = (time.time() - _yCE.uploadedLastAttempt) / 60.0
-    logger.debug("Intervals %s, time since last call %s, last call %s" %
-                 (_yCE.uploadInterval, minFromLastUpload,
-                  _yCE.uploadLastTime))
-    if (((_yCE.accountSecret != '') and 
-         (not _yCE.accountSecretIncorrectFlag) and 
-         (minFromLastUploadAttempt > 1)) and
-        ((forceUpload  and minFromLastUpload > _yCE.uploadIntervalMin) or
-         (upload and (minFromLastUpload >= _yCE.uploadInterval))
-         )):
-        _ykrUpload(tables=_yCE.tables)
+    if ((_yCE.accountSecret != '') and (not _yCE.accountSecretIncorrectFlag)):
+        minFromLastUpload = (time.time() - _yCE.uploadLastTime) / 60.0
+        # minFromLastUploadAttempt = (time.time() -
+        #                             _yCE.uploadedLastAttempt) / 60.0
+        # TODO add check for minFromLastUploadAttempt
+        lapseFlag = minFromLastUpload >= _yCE.uploadIntervalMin
+        logger.debug("Intervals %s, time since last call %s, last call %s" %
+                     (_yCE.uploadInterval, minFromLastUpload,
+                      _yCE.uploadLastTime))
+        if (((forceUpload or upload) and lapseFlag) or 
+             (forceUpload  and (not _yCE.forceLoadUsed))):
+            _ykrUpload(tables=_yCE.tables)
+            if forceUpload and (not _yCE.forceLoadUsed):
+                            _yCE.forceLoadUsed = True
     if removeHistory:
         _params_RemoveHistory()
+        
+# def _ykrUpdate(df=None, upload=True, removeHistory=True, forceUpload=False):
+#     if df is not None:
+#         _ykrUpdateInfo(df=df)
+#     minFromLastUpload = (time.time() - _yCE.uploadLastTime) / 60.0
+#     minFromLastUploadAttempt = (time.time() - _yCE.uploadedLastAttempt) / 60.0
+#     logger.debug("Intervals %s, time since last call %s, last call %s" %
+#                  (_yCE.uploadInterval, minFromLastUpload,
+#                   _yCE.uploadLastTime))
+#     if (((_yCE.accountSecret != '') and 
+#          (not _yCE.accountSecretIncorrectFlag)) and 
+#          # (minFromLastUploadAttempt > 1) or (not _yCE.forceLoadUsed)) and
+#         ((forceUpload  and minFromLastUpload > _yCE.uploadIntervalMin) or
+#          (forceUpload  and (not _yCE.forceLoadUsed)) or
+#          (upload and (minFromLastUpload >= _yCE.uploadInterval))
+#          )):
+#         _ykrUpload(tables=_yCE.tables)
+#     if forceUpload and (not _yCE.forceLoadUsed):
+#         print("gadi - updated code run")
+#         _yCE.forceLoadUsed = True
+#     if removeHistory:
+#         _params_RemoveHistory()
 
 
 def _reloadConfigFiles():
@@ -258,7 +285,8 @@ def _onLoad():
     _ykrStartup()
     df = _ykrGetLibsInfo()
     _print_libs(info=df)
-    _ykrUpdate(df=df, forceUpload=True)
+#    _ykrUpdate(df=df, forceUpload=True)
+    _ykrUpdate(df=df, upload=True)
     logger.info("Yokaranda Loaded")
 
 
@@ -450,7 +478,7 @@ def _fixVal(entity=None, infoDict=None, field=None):
             elif (field == "instDataRetantionDays"):
                 val = _isIntRangeOK(val, 2, 30, field, entity)
             elif (field == "max_result_size"):
-                val = _isIntRangeOK(val, 1000, 10000, field, entity)
+                val = _isIntRangeOK(val, 1000, 20000, field, entity)
         except ValueError:
             logger.error(".%sDCF.txt file, field %s integer expected found %s"
                          % (entity, field, val))
@@ -801,7 +829,7 @@ def _sendTable(con=None, cursor=None, query=None, args=None,
                 data = dict()
                 rowIds = []
             chunk = cursor.fetchmany(size=_yCE.max_result_size)
-    return(data, rowIds)
+    return(data, rowIds) # TODO
 
 
 def _getLastUploadTime(cursor=None):
@@ -937,7 +965,7 @@ def _ykrUpload(tables=None):
                 tmpLst = list(tab)
                 tmpLst[0] = 'InstanceDataAgg'
                 tab = tuple(tmpLst)
-                _fromData2AggLocalDB()
+                _fromData2AggLocalDB() # TODO
                 query = 'SELECT rowid,* FROM %s WHERE Uploaded = ?' % tab[0]
                 args = (0,)
             elif tab[0] == 'UsedEntities':
